"""
Type annotations for codestar-notifications service client paginators.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_codestar_notifications/paginators/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_codestar_notifications.client import CodeStarNotificationsClient
    from types_boto3_codestar_notifications.paginator import (
        ListEventTypesPaginator,
        ListNotificationRulesPaginator,
        ListTargetsPaginator,
    )

    session = Session()
    client: CodeStarNotificationsClient = session.client("codestar-notifications")

    list_event_types_paginator: ListEventTypesPaginator = client.get_paginator("list_event_types")
    list_notification_rules_paginator: ListNotificationRulesPaginator = client.get_paginator("list_notification_rules")
    list_targets_paginator: ListTargetsPaginator = client.get_paginator("list_targets")
    ```
"""

from __future__ import annotations

import sys
from typing import TYPE_CHECKING

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    ListEventTypesRequestPaginateTypeDef,
    ListEventTypesResultTypeDef,
    ListNotificationRulesRequestPaginateTypeDef,
    ListNotificationRulesResultTypeDef,
    ListTargetsRequestPaginateTypeDef,
    ListTargetsResultTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack

__all__ = ("ListEventTypesPaginator", "ListNotificationRulesPaginator", "ListTargetsPaginator")

if TYPE_CHECKING:
    _ListEventTypesPaginatorBase = Paginator[ListEventTypesResultTypeDef]
else:
    _ListEventTypesPaginatorBase = Paginator  # type: ignore[assignment]

class ListEventTypesPaginator(_ListEventTypesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codestar-notifications/paginator/ListEventTypes.html#CodeStarNotifications.Paginator.ListEventTypes)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_codestar_notifications/paginators/#listeventtypespaginator)
    """
    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListEventTypesRequestPaginateTypeDef]
    ) -> PageIterator[ListEventTypesResultTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codestar-notifications/paginator/ListEventTypes.html#CodeStarNotifications.Paginator.ListEventTypes.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_codestar_notifications/paginators/#listeventtypespaginator)
        """

if TYPE_CHECKING:
    _ListNotificationRulesPaginatorBase = Paginator[ListNotificationRulesResultTypeDef]
else:
    _ListNotificationRulesPaginatorBase = Paginator  # type: ignore[assignment]

class ListNotificationRulesPaginator(_ListNotificationRulesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codestar-notifications/paginator/ListNotificationRules.html#CodeStarNotifications.Paginator.ListNotificationRules)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_codestar_notifications/paginators/#listnotificationrulespaginator)
    """
    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListNotificationRulesRequestPaginateTypeDef]
    ) -> PageIterator[ListNotificationRulesResultTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codestar-notifications/paginator/ListNotificationRules.html#CodeStarNotifications.Paginator.ListNotificationRules.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_codestar_notifications/paginators/#listnotificationrulespaginator)
        """

if TYPE_CHECKING:
    _ListTargetsPaginatorBase = Paginator[ListTargetsResultTypeDef]
else:
    _ListTargetsPaginatorBase = Paginator  # type: ignore[assignment]

class ListTargetsPaginator(_ListTargetsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codestar-notifications/paginator/ListTargets.html#CodeStarNotifications.Paginator.ListTargets)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_codestar_notifications/paginators/#listtargetspaginator)
    """
    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListTargetsRequestPaginateTypeDef]
    ) -> PageIterator[ListTargetsResultTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codestar-notifications/paginator/ListTargets.html#CodeStarNotifications.Paginator.ListTargets.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_codestar_notifications/paginators/#listtargetspaginator)
        """



"""
Setup script for types-boto3-codestar-notifications.

Copyright 2025 Vlad Emelianov
"""

from pathlib import Path

from setuptools import setup  # type: ignore

LONG_DESCRIPTION = (Path(__file__).parent / "README.md").read_text()


setup(
    name="types-boto3-codestar-notifications",
    version="1.40.17",
    packages=["types_boto3_codestar_notifications"],
    url="https://github.com/youtype/mypy_boto3_builder",
    license="MIT License",
    author="Vlad Emelianov",
    author_email="vlad.emelianov.nz@gmail.com",
    description="Type annotations for boto3 CodeStarNotifications 1.40.17 service generated with mypy-boto3-builder 8.11.0",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Environment :: Console",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: English",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Programming Language :: Python :: 3.13",
        "Programming Language :: Python :: 3.14",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: Implementation :: CPython",
        "Typing :: Stubs Only",
    ],
    keywords="boto3 codestar-notifications boto3-stubs type-annotations mypy typeshed autocomplete",
    long_description=LONG_DESCRIPTION,
    long_description_content_type="text/markdown",
    package_data={"types_boto3_codestar_notifications": ["py.typed", "*.pyi"]},
    python_requires=">=3.8",
    project_urls={
        "Documentation": "https://youtype.github.io/types_boto3_docs/types_boto3_codestar_notifications/",
        "Source": "https://github.com/youtype/mypy_boto3_builder",
        "Tracker": "https://github.com/youtype/mypy_boto3_builder/issues",
    },
    install_requires=['typing-extensions; python_version<"3.12"'],
    zip_safe=False,
)
